Stocktwits
----------

App Registration
  https://api.stocktwits.com/developers/apps/new

- Site Domain, Must be an external url (127.0.0.1 and localhost do not work).
- Consumer key is your ``client id``
- Consumer secret is your ``secret key``
